pub struct StyledSpan {
pub start: usize,
pub end: usize,
pub fg: Option<AnsiColor>,
pub bg: Option<AnsiColor>,
pub bold: bool,
pub italic: bool,
pub underline: bool,
pub dim: bool,
}Expand description
Style information for a span of text within a line.
Fields
start: usizeStart byte offset in the cleaned content.
end: usizeEnd byte offset (exclusive) in the cleaned content.
fg: Option<AnsiColor>Foreground color.
bg: Option<AnsiColor>Background color.
bold: boolitalic: boolunderline: booldim: boolTrait Implementations
Sourceimpl Clone for StyledSpan
impl Clone for StyledSpan
Sourcefn clone(&self) -> StyledSpan
fn clone(&self) -> StyledSpan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StyledSpan
impl Debug for StyledSpan
Sourceimpl PartialEq for StyledSpan
impl PartialEq for StyledSpan
Sourcefn eq(&self, other: &StyledSpan) -> bool
fn eq(&self, other: &StyledSpan) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for StyledSpan