Module unicode

Module unicode 

Functions

compute_display_widths
Compute the display width of each character in the string.
display_col_to_char_range
Given a string and a display column range [col_start, col_end), return the char range that covers those display columns.
display_width
Compute the total display width of a string.