Functions
- compute_
display_ widths - Compute the display width of each character in the string.
- display_
col_ to_ char_ range - Given a string and a display column range [col_start, col_end), return the char range that covers those display columns.
- display_
width - Compute the total display width of a string.